@@ -15,6 +15,8 @@ VENV_NAME = "magic_venv"
 
 REPO_NAME = "jerber/MagicAPI-Boilerplate"
 
+MAIN_FILENAME = "main.py"
+
 
 @app.command()
 def sowell():
@@ -106,9 +108,25 @@ def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
     os.system(command)
 
 
+@app.command()
+def start():
+    typer.secho(
+        "To get interactive docs, go to http://0.0.0.0:8000/docs 🎩!",
+        fg=typer.colors.BRIGHT_GREEN,
+    )
+    command = f"python {MAIN_FILENAME}"
+    os.system(command)
+
+
+@app.command()
+def test():
+    command = f"pytest -s -v"
+    os.system(command)
+
+
 @app.command()
 def version():
-    typer.echo("8")
+    typer.echo("9")
 
 
 if __name__ == "__main__":
